package com.example.ueberwachungssystem;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.camera.view.PreviewView;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import androidx.camera.core.ExperimentalGetImage;

import android.Manifest;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.os.Environment;
import android.view.SurfaceView;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.ToggleButton;
import android.widget.VideoView;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.Array;
import java.util.Arrays;

@ExperimentalGetImage
public class MainActivity extends AppCompatActivity {

    private static final int PERMISSION_REQUEST_CODE = 111;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        TextView textView = findViewById(R.id.textView);
        SurfaceView surfaceView = findViewById(R.id.surfaceView);
        VideoView videoView = findViewById(R.id.videoView);

        File directory = getFilesDir();


        Recorder recorder = new Recorder(this);
        recorder.setSurfaceView(surfaceView);


        ToggleButton toggleButton = findViewById(R.id.previewButton);
        toggleButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                getRecordVideoAccess();

                if (isRecordVideoAllowed() && toggleButton.isChecked())
                {
                    //textView.setText(file.getAbsolutePath());
                    recorder.startRecording();

                    File file = new File(directory, "file.txt");

                    try {
                        file.createNewFile();
                    } catch (IOException e) {
                        throw new RuntimeException(e);
                    }

                }
                else {
                    File[] files = directory.listFiles();
                    //textView.setText(Arrays.toString(files));
                    recorder.stopRecording();
                    recorder.playVideo(videoView);
                }
            }
        });
    }

    private boolean isRecordVideoAllowed() {
        return ContextCompat.checkSelfPermission(this, Manifest.permission.CAMERA) == PackageManager.PERMISSION_GRANTED &&
                ContextCompat.checkSelfPermission(this, Manifest.permission.RECORD_AUDIO) == PackageManager.PERMISSION_GRANTED;
    }

    private void getRecordVideoAccess() {
        if (!isRecordVideoAllowed()) {
            ActivityCompat.requestPermissions(this, new String[]{Manifest.permission.CAMERA, Manifest.permission.RECORD_AUDIO}, PERMISSION_REQUEST_CODE);
        }
    }


    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);

        if (requestCode == PERMISSION_REQUEST_CODE && grantResults.length > 0) {

            boolean cameraRights = grantResults[0] == PackageManager.PERMISSION_GRANTED;
            boolean recordAudioRights = grantResults[1] == PackageManager.PERMISSION_GRANTED;

            if (cameraRights && recordAudioRights) {
                Toast.makeText(this, "permissions granted", Toast.LENGTH_LONG).show();
            } else {
                Toast.makeText(this, "permissions denied", Toast.LENGTH_LONG).show();
            }
        }
    }
}