package com.example.ueberwachungssystem;

import android.content.Context;
import android.hardware.Camera;
import android.media.CamcorderProfile;
import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.widget.VideoView;
import java.io.IOException;

public class Recorder {

    private final Context context;
    private Camera camera;
    private MediaRecorder mediaRecorder = null;
    private SurfaceView surfaceView;

    public Recorder (Context context) {
        this.context = context;
        this.surfaceView = new SurfaceView(context);
    }


    public void startRecording() {
        try {
            // Open the camera
            camera = Camera.open();
            camera.setPreviewDisplay(surfaceView.getHolder());
            camera.startPreview();

            camera.unlock();

            // Create a new MediaRecorder instance
            mediaRecorder = new MediaRecorder();

            // Set the camera as the video source
            mediaRecorder.setCamera(camera);

            // Set the audio and video source
            mediaRecorder.setAudioSource(MediaRecorder.AudioSource.CAMCORDER);
            mediaRecorder.setVideoSource(MediaRecorder.VideoSource.CAMERA);


            CamcorderProfile camcorderProfile = CamcorderProfile.get(CamcorderProfile.QUALITY_HIGH);
            mediaRecorder.setProfile(camcorderProfile);

            // Set the output file path
            mediaRecorder.setOutputFile(context.getFilesDir() + "/video.mp4");


            mediaRecorder.prepare();
            mediaRecorder.start();

        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void stopRecording() {
        if (mediaRecorder != null) {
            try {
                mediaRecorder.stop();
                mediaRecorder.reset();
                mediaRecorder.release();
                mediaRecorder = null;
            } catch (RuntimeException e) {
                // RuntimeException may be thrown if the MediaRecorder is in an invalid state
                e.printStackTrace();
            }

            if (camera != null) {
                try {
                    camera.reconnect();
                    camera.stopPreview();
                    camera.lock();
                    camera.release();
                    camera = null;
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public void setSurfaceView(SurfaceView surfaceView) {
        this.surfaceView = surfaceView;
    }


    private void playAudio() {
        MediaPlayer mp = new MediaPlayer();
        try {
            mp.setDataSource(context.getFilesDir() + "/audio.gpp");
            mp.prepare();
            mp.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void playVideo(VideoView videoView) {
        videoView.setVideoPath(context.getFilesDir() + "/video.mp4");
        videoView.start();
    }
}
